@@ -5,11 +5,10 @@ import argparse
 import binascii
 
 import flirt
+import vivisect.const
 
 import viv_utils
 import viv_utils.flirt
-import vivisect.const
-
 
 logger = logging.getLogger("get_flirt_matches")
 
@@ -41,12 +40,8 @@ def get_workspace(path, sigpaths):
 
 def main():
     parser = argparse.ArgumentParser()
-    parser.add_argument(
-        "-d", "--debug", action="store_true", help="enable debugging output on STDERR"
-    )
-    parser.add_argument(
-        "-q", "--quiet", action="store_true", help="disable all output but errors"
-    )
+    parser.add_argument("-d", "--debug", action="store_true", help="enable debugging output on STDERR")
+    parser.add_argument("-q", "--quiet", action="store_true", help="disable all output but errors")
     parser.add_argument(
         "signature",
         type=str,
